<?php
/*
 * Plugin Name:       RefineURL
 * Plugin URI:        https://wordpress.org/plugins/refineurl
 * Description:       Allows you to change and redirect different URLs of your WordPress website.
 * Version:           0.0.1
 * Requires at least: 5.2
 * Requires PHP:      7.2
 * Author:            Asadullah Galib
 * License:           GPL v2 or later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:       refineurl
 * Domain Path:       /languages
 */


if (!defined('ABSPATH')) {
    exit;
}

// The key prefix Upper-case: SAPRFURL, lower-case: saprfurl

// Define constants
define('SAPRFURL_VERSION', '0.0.1');
define('SAPRFURL_ASSETS', plugin_dir_url(__FILE__) . 'assets/');
define('SAPRFURL_TEMPLATES', plugin_dir_path(__FILE__) . 'templates/');

// Enqueue CSS and JS files
function saprfurl_enqueue_admin_assets() {
    wp_enqueue_style('saprfurl-admin-style', SAPRFURL_ASSETS . 'css/admin-style.css', [], SAPRFURL_VERSION, 'all');
}
add_action('admin_enqueue_scripts', 'saprfurl_enqueue_admin_assets');

// Register the plugin menu in the admin sidebar
function saprfurl_register_admin_menu() {
    $capability = 'manage_options';
    $parent_slug = 'refineurl';

    add_menu_page(
        esc_html__('RefineURL', 'refineurl'),
        esc_html__('RefineURL', 'refineurl'),
        $capability,
        $parent_slug,
        'saprfurl_url_change_page',
        'dashicons-editor-unlink',
        20
    );
}
add_action('admin_menu', 'saprfurl_register_admin_menu');

// Plugin settings page
function saprfurl_url_change_page() {
    $saprfurl_settings_template = SAPRFURL_TEMPLATES . 'settings.php';

    if (file_exists($saprfurl_settings_template)) {
        include $saprfurl_settings_template;
    } else {
        ?>
        <div class="notice notice-warning is-dismissible">
            <h2><?php echo esc_html__('Add the platform type:', 'refineurl'); ?></h2>
        </div>
        <?php
    }
}

// Retrieve the option value
function saprfurl_get_hide_login_page() {
    return get_option('saprfurl_hide_login_page', 1);
}

// Restrict wp-admin and wp-login.php
function saprfurl_restrict_wp_admin_and_login() {
    if (!is_user_logged_in()) {
        if (isset($_SERVER['REQUEST_URI'])) {
            // Unslash and sanitize REQUEST_URI
            $saprfurl_request_uri = esc_url_raw(wp_unslash($_SERVER['REQUEST_URI']));
            
            if (strpos($saprfurl_request_uri, 'wp-admin') !== false || strpos($saprfurl_request_uri, 'wp-login.php') !== false) {
                wp_redirect(home_url('/404'));
                exit;
            }
        }
    }
}


// Conditionally restrict access if setting is enabled
if (saprfurl_get_hide_login_page()) {
    add_action('init', 'saprfurl_restrict_wp_admin_and_login');
}